local numbs = 10

use "curstream.dta"
summ stream
local stream = r(mean)

cap log using "log`stream'.log", replace

di "Stream: `stream'"

set rng mt64s
set rngstream `stream'
set seed 519

local stream = c(rngstream)

do "reweight_est_impute.ado"
	
forvalues b = 1(1)`numbs' {
	di as result "Bootstrap `b' of `numbs'"

	use "ready_to_reweight.dta", clear
		unique sid2
		local numclusters = r(sum)
		bsample `numclusters', cluster(sid2)
		
		reweight_est bcg_z
			scalar effect_ik= r(effect)
			scalar effect_ik_a = r(effect_a)
			scalar effect_ik_b = r(effect_b)
			scalar effect_ik_res = r(effect_res)
			scalar effect_ik_a_res = r(effect_a_res)
			scalar effect_ik_b_res = r(effect_b_res)
			scalar samplesize_ik = r(samplesize)
			scalar samplesize_ik_res = r(samplesize_res)
			
			scalar effect_cct = r(effect_cct)
			scalar effect_cct_a = r(effect_a_cct)
			scalar effect_cct_b = r(effect_b_cct)
			scalar effect_cct_res = r(effect_res_cct)
			scalar effect_cct_a_res = r(effect_a_res_cct)
			scalar effect_cct_b_res = r(effect_b_res_cct)
			scalar samplesize_ik_cct = r(samplesize_cct)
			scalar samplesize_ik_res_cct = r(samplesize_res_cct)
		
		reweight_est bcg_z, reweight
			scalar effect_ikrw = r(effect)
			scalar effect_ikrw_a = r(effect_a)
			scalar effect_ikrw_b = r(effect_b)
			scalar effect_ikrw_res = r(effect_res)
			scalar effect_ikrw_a_res = r(effect_a_res)
			scalar effect_ikrw_b_res = r(effect_b_res)
			scalar samplesize_ikrw = r(samplesize)
			scalar samplesize_ikrw_res = r(samplesize_res)
			
			scalar effect_cctrw = r(effect_cct)
			scalar effect_cctrw_a = r(effect_a_cct)
			scalar effect_cctrw_b = r(effect_b_cct)
			scalar effect_cctrw_res = r(effect_res_cct)
			scalar effect_cctrw_a_res = r(effect_a_res_cct)
			scalar effect_cctrw_b_res = r(effect_b_res_cct)
			scalar samplesize_cctrw = r(samplesize_cct)
			scalar samplesize_cctrw_res = r(samplesize_res_cct)
			
		clear
		set obs 1
		
		foreach suff in "ikrw" "ik" "cctrw" "cct" {
			gen effect_`suff' = scalar(effect_`suff')
			gen effect_`suff'_a = scalar(effect_`suff'_a)
			gen effect_`suff'_b = scalar(effect_`suff'_b)
			gen effect_`suff'_res = scalar(effect_`suff'_res)
			gen effect_`suff'_a_res = scalar(effect_`suff'_a_res)
			gen effect_`suff'_b_res = scalar(effect_`suff'_b_res)
		}
		
		keep effect*
		
		gen stream = "`stream'"
		gen b = `b'
		capture confirm file "bootstrap_estimates.dta"
		if !_rc {
			append using "bootstrap_estimates.dta"
		}
		save "bootstrap_estimates.dta", replace
}
cap log close

exit, STATA clear
