
/* This code takes the original survey data surveyY567.dta to generate the JHR replication data JHR_data_5 */


clear all
set more off
use surveyY567, clear

**********************************
*** Kiki's initial definitions ***
**********************************

gen a=string(ua)
gen b=string(z) 
gen c=string(Y) 
gen d=string(sid) 
gen e="Y"
gen f="z"
gen h=string(us)

generate fx=a+b+c 
generate uazY=a+f+b+e+c 
list ua z Y uazY in 1/10
generate sid2=d+e+c
generate uaY=a+c
gen us2BY=us2B+c
gen usY=h+c

gen dg =1 if dzg >=0 
replace dg =0 if dzg <0
gen dga=1 if dzag>=0 
replace dga=0 if dzag<0
gen dk =1 if dzk >=0 
replace dk =0 if dzk <0
gen dka=1 if dzak>=0 
replace dka=0 if dzak<0
gen dgdzg=dg*dzg

gen dzg2 =dzg *dzg 
gen dzag2=dzag*dzag
gen dzg3=dzg*dzg*dzg
gen dzag_after=dzag*dg
gen dzg_after=dzg*dg
gen dzg2_after=dzg2*dg
gen dzg3_after=dzg3*dg
gen dzgr01=round(dzg,.001) 
gen dzgr05=round(dzg,.050)
gen dzkr2 =round(dzk,   2) if dzk~=0
gen dzkr5 =round(dzk,   5) 

egen bct_z05 = std(bct) if Y==5
egen bct_z06 = std(bct) if Y==6
egen bct_z07 = std(bct) if Y==7
gen bct_z=.
replace bct_z= bct_z05 if Y==5
replace bct_z= bct_z06 if Y==6
replace bct_z= bct_z07 if Y==7

egen bcg_z05 = std(bcg) if Y==5
egen bcg_z06 = std(bcg) if Y==6
egen bcg_z07 = std(bcg) if Y==7
gen bcg_z=.
replace bcg_z= bcg_z05 if Y==5
replace bcg_z= bcg_z06 if Y==6
replace bcg_z= bcg_z07 if Y==7

egen bcgr_z05 = std(bcgr) if Y==5
egen bcgr_z06 = std(bcgr) if Y==6
egen bcgr_z07 = std(bcgr) if Y==7
gen bcgr_z=.
replace bcgr_z= bcgr_z05 if Y==5
replace bcgr_z= bcgr_z06 if Y==6
replace bcgr_z= bcgr_z07 if Y==7

*****************************
**** Kiki's restrictions ****
*****************************

keep if selection4==1
keep if z==nusua-1

drop if ua==20304 & Y==6
drop if ua==20572 & Y==6
drop if ua==35740 & Y==6
drop if ua==100585 & Y==6
drop if ua==36015 & Y==6
drop if ua==101305 & Y==6


gen int y=2000+Y
keep if (year==1990 & y==2005) | (year==1991 & y==2006)
keep if (bmonth>=1 & bmonth<=12)

gen academic=(prsp==1 | prsp==2 | prsp==4 | prsp==5)

*************************************
**** Rename household education  ****
*************************************

rename (head_educ head_occ) (head_occ head_educ)
rename (mom_educ mom_occ) (mom_occ mom_educ)
rename (dad_educ dad_occ) (dad_occ dad_educ)

gen head_educ_high=(head_educ==6 | head_educ==8) if head_educ!=. 
gen mom_educ_high=(mom_educ==6 | mom_educ==8) if mom_educ!=. 
gen dad_educ_high=(dad_educ==6 | dad_educ==8) if dad_educ!=. 



***********************************
**** Extra variables defitions ****
***********************************

* main variables
gen early=(bmonth>=1 & bmonth<=6) if (bmonth>=1 & bmonth<=12)
gen late=(bmonth>=7 & bmonth<=12) if (bmonth>=1 & bmonth<=12)
gen b1990=(year==1990) 
gen b1991=(year==1991)
gen unwanted=early*b1990
gen wanted=!unwanted
gen dga_wanted=dga*wanted

* kiki's definitions
drop after cohort
gen before=early
gen cohort=b1991
gen dzag_dga=dzag*dga

* main interactions
gen dzag_wanted=dzag*wanted
gen dzag_dga_wanted=dzag_dga*wanted

* additional interactions for spec1
gen trend=bmonth
gen trend2=bmonth*bmonth
gen trend_dga=trend*dga
gen trend2_dga=trend2*dga
gen trend_dzag=trend*dzag
gen trend2_dzag=trend2*dzag
gen trend_dzag_dga=trend*dzag_dga
gen trend2_dzag_dga=trend2*dzag_dga

* additional interactions for spec2
gen dga_cohort=dga*cohort
gen dzag_cohort=dzag*cohort
gen dzag_dga_cohort=dzag_dga*cohort 

* additional interactions for spec3
forvalues month=1/12 {
	gen bmonth`month'=(bmonth==`month')
	gen bmonth_dga`month'=bmonth`month'*dga
	gen bmonth_dzag`month'=bmonth`month'*dzag
	gen bmonth_dzag_dga`month'=bmonth`month'*dzag_dga
}

* additional interactions for spec4
gen dga_before=dga*before 
gen dzag_before=dzag*before
gen dzag_dga_before=dzag_dga*before 


gen mom_age=2010-mom_byear if mom_byear>1910
gen dad_age=2010-dad_byear if dad_byear>1910
gen head_age=2010-head_byear


******************************
**** Keep main variables  ****
******************************

keep p_d_homework_help ch_d_homework p_tutoring agus dga dzag uazY usY us2BY sid2 dga wanted dga_wanted dzag dzag_dga before dga_before dzag_wanted dzag_before dzag_dga_wanted dzag_dga_before cohort dga_cohort dzag_cohort dzag_dga_cohort trend trend_dga trend_dzag trend_dzag_dga 

*extra controls variables
*mom_age mom_educ_high mom_nat_romanian mom_nat_hungarian mom_nat_gypsy dad_age dad_educ_high
*head_sex head_age head_educ_high head_nat_romanian head_nat_hungarian head_nat_gypsy


************************
**** Save new file  ****
************************

save JHR_data_5, replace

